@@ -65,8 +65,6 @@ enum {
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
-static void     gsm_systemd_class_init   (GsmSystemdClass *klass);
-static void     gsm_systemd_init         (GsmSystemd      *sd);
 static void     gsm_systemd_finalize     (GObject         *object);
 
 static void     gsm_systemd_free_dbus    (GsmSystemd      *manager);
@@ -836,17 +834,17 @@ gsm_systemd_can_hibernate (GsmSystemd *manager)
   gboolean can_hibernate;
   GError  *error;
   GsmSystemdPrivate *priv;
-  
+
   error = NULL;
   priv = gsm_systemd_get_instance_private (manager);
-  
+
   if (!gsm_systemd_ensure_sd_connection (manager, &error)) {
     g_warning ("Could not connect to Systemd: %s",
                error->message);
     g_error_free (error);
     return FALSE;
   }
-  
+
   res = dbus_g_proxy_call_with_timeout (priv->sd_proxy,
                                         "CanHibernate",
                                         INT_MAX,
@@ -860,7 +858,7 @@ gsm_systemd_can_hibernate (GsmSystemd *manager)
     g_error_free (error);
     return FALSE;
   }
-  
+
   can_hibernate = g_strcmp0 (value, "yes") == 0 ||
   g_strcmp0 (value, "challenge") == 0;
   g_free (value);
@@ -875,17 +873,17 @@ gsm_systemd_can_suspend (GsmSystemd *manager)
   gboolean can_suspend;
   GError  *error;
   GsmSystemdPrivate *priv;
-  
+
   error = NULL;
   priv = gsm_systemd_get_instance_private (manager);
-  
+
   if (!gsm_systemd_ensure_sd_connection (manager, &error)) {
     g_warning ("Could not connect to Systemd: %s",
                error->message);
     g_error_free (error);
     return FALSE;
   }
-  
+
   res = dbus_g_proxy_call_with_timeout (priv->sd_proxy,
                                         "CanSuspend",
                                         INT_MAX,
@@ -899,7 +897,7 @@ gsm_systemd_can_suspend (GsmSystemd *manager)
     g_error_free (error);
     return FALSE;
   }
-  
+
   can_suspend = g_strcmp0 (value, "yes") == 0 ||
   g_strcmp0 (value, "challenge") == 0;
   g_free (value);
@@ -912,17 +910,17 @@ gsm_systemd_attempt_hibernate (GsmSystemd *manager)
   gboolean res;
   GError  *error;
   GsmSystemdPrivate *priv;
-  
+
   error = NULL;
   priv = gsm_systemd_get_instance_private (manager);
-  
+
   if (!gsm_systemd_ensure_sd_connection (manager, &error)) {
     g_warning ("Could not connect to Systemd: %s",
                error->message);
     g_error_free (error);
     return;
   }
-  
+
   res = dbus_g_proxy_call_with_timeout (priv->sd_proxy,
                                         "Hibernate",
                                         INT_MAX,
@@ -936,7 +934,7 @@ gsm_systemd_attempt_hibernate (GsmSystemd *manager)
     g_error_free (error);
     return;
   }
-  
+
 }
 
 void
@@ -945,17 +943,17 @@ gsm_systemd_attempt_suspend (GsmSystemd *manager)
   gboolean res;
   GError  *error;
   GsmSystemdPrivate *priv;
-  
+
   error = NULL;
   priv = gsm_systemd_get_instance_private (manager);
-  
+
   if (!gsm_systemd_ensure_sd_connection (manager, &error)) {
     g_warning ("Could not connect to Systemd: %s",
                error->message);
     g_error_free (error);
     return;
   }
-  
+
   res = dbus_g_proxy_call_with_timeout (priv->sd_proxy,
                                         "Suspend",
                                         INT_MAX,
