@@ -77,8 +77,6 @@ enum {
         PROP_CLIENT_STORE
 };
 
-static void     gsm_xsmp_server_class_init  (GsmXsmpServerClass *klass);
-static void     gsm_xsmp_server_init        (GsmXsmpServer      *xsmp_server);
 static void     gsm_xsmp_server_finalize    (GObject         *object);
 
 static gpointer xsmp_server_object = NULL;
@@ -697,7 +695,7 @@ gsm_xsmp_server_finalize (GObject *object)
 
         xsmp_server = GSM_XSMP_SERVER (object);
 
-        IceFreeListenObjs (xsmp_server->num_xsmp_sockets, 
+        IceFreeListenObjs (xsmp_server->num_xsmp_sockets,
                            xsmp_server->xsmp_sockets);
 
         if (xsmp_server->client_store != NULL) {
